#!/usr/bin/env python
# -*- encoding: utf-8 -*-


from utils import add
# 导入要写单元测试的函数或逻辑
# from module_name import methods


class TestApp():


    """ 
    单元测试示例
    """

    def test_add(self):
        """
        函数必须为 test_xxx 开头
        """
        res = add(1,2)
        print("test_add",res)
        assert  res!=3



#!/usr/bin/env python
# -*- encoding: utf-8 -*-


from .app_static import get_logger_file

import logging

# 日期格式
DATE_FORMAT = "%Y-%m-%d %H:%M:%S"
# 日志格式
BASIC_FORMAT = '[%(asctime)s][%(threadName)s][%(levelname)s][ %(filename)s:%(lineno)s] : %(message)s '
# 日期内容格式
LOG_FORMAT = logging.Formatter(BASIC_FORMAT, DATE_FORMAT)
LOG_FILE = get_logger_file()

LOG_CONSOLE_HANDLER = logging.StreamHandler()

class AppLogger():
    """
    LOG 
    """

    def __init__(self):
        # 日志对象
        self.logger = logging.getLogger("ROI")
        # 日志文件
        LOG_CONSOLE_HANDLER.setFormatter(LOG_FORMAT)
        LOG_CONSOLE_HANDLER.setLevel(logging.INFO)
        self.logger.addHandler(LOG_CONSOLE_HANDLER)


logger = AppLogger().logger



import importlib
import os
import sys

from .roi_ctl import *

# MODULE REGISTER
globals().update(importlib.import_module('roi_ctl').__dict__)

# STATIC PATH
if sys.platform.startswith('linux'):
	os.environ['ROI_CTL_STATIC'] = os.path.dirname(os.path.abspath(__file__))


#!/usr/bin/env python
# -*- encoding: utf-8 -*-


"""
测试主函数
"""

import pytest


if __name__=="__main__":
    # 全部用例文件
    pytest.main(["tests","-s"])
    # 单个用例文件
    pytest.main(["tests/test_app.py","-s"])




#!/usr/bin/env python
# -*- encoding: utf-8 -*-


from os.path import dirname, abspath, join, exists

import os
import datetime

"""
必须放到 MODULE_NAME 根路径
"""


def get_static():
    """
    获取静态资源路径
    """
    dirname_root = dirname(dirname(abspath(__file__)))
    return join(dirname_root, "static")


def get_logger_file():
    """
    日志存储文件夹 
    ---
    static/logs/
    """
    dir_static = get_static()
    dir_logger = join(dir_static, "logs")
    if not exists(dir_logger):
        os.makedirs(dir_logger)
    logger_file_name = str(datetime.date.today()).replace("-", "")
    logger_file = join(dir_logger, f"{logger_file_name}.log")
    return logger_file



#!/usr/bin/env python
# -*- encoding: utf-8 -*-


from os.path import dirname, abspath, join


"""
必须放到 MODULE_NAME 根路径
"""


def get_static():
    """
    获取静态资源路径
    """
    dirname_root = dirname(dirname(abspath(__file__)))
    return join(dirname_root, "static")




#!/usr/bin/env python
# -*- encoding: utf-8 -*-

import os
import json

class AppProduct:
    """
    运行环境
    """

    def __init__(self):
        """
        环境变量
        """
        # 日志
        self.IS_DEBUG = True
        # 声明环境变量: product.json 保持一致

    def create():
        # 环境
        env_code = "debug"
        if "ENV" in os.environ:
            env_code = os.environ["ENV"]
        envs = {}
        with open("product.json", "r") as file:
            envs = json.loads(file.read())["envs"]
        runtime = envs[env_code]
        # 环境变量
        if "IS_DEBUG" in os.environ:
            runtime["IS_DEBUG"] = os.environ["IS_DEBUG"]
        # 初始化配置
        prod = AppProduct()
        prod.__dict__ = runtime
        return prod


# exports product
product = AppProduct.create()



from setuptools import setup, find_packages
setup(
name='roi-ctl',
version='1.0.9',
description='Change Module Infomation',
author_email='ops@smartahc.com',
author='roictl',
license='smartahc',
keywords=['roi_ctl'],
packages=find_packages(),
include_package_data=True,
install_requires=['click==8.0.3', 'twine==3.5.0', 'nuitka==0.6.17.5', 'requests==2.25.1', 'pytest==6.2.5'],
python_requires='>=3.8',
entry_points="""
[console_scripts]
roictl=roi_ctl:cli
"""
)


#!/usr/bin/env python
# -*- encoding: utf-8 -*-

"""
   @File    :   __init__.py
   @Create  :   2021/09/06 19:45:16
   @Author  :   Your Name
   @Update  :   2021/09/06
   @License :   (C)Copyright 2014-2021 SmartAHC All Rights Reserved 
   @Desc    :   Coding Below
"""

from .app_product import product
from .app_logger import logger, BASIC_FORMAT

import logging
import json


class App():

    """
    项目主入口
    """

    def __init__(self):
        """
        根据需要初始化
        """
        if product.IS_DEBUG:
            logging.basicConfig(level=logging.DEBUG, format=BASIC_FORMAT)
        else:
            logging.basicConfig(level=logging.ERROR, format=BASIC_FORMAT)
        # 打印配置信息
        CONFIG = json.dumps(product.__dict__, indent=4)
        logger.info("----------------------------------------------------")
        if product.IS_DEBUG:
            logger.debug(CONFIG)
        else:
            logger.info(f"DEBUG: {product.IS_DEBUG}")
        logger.info("----------------------------------------------------")
        logger.debug("APP RUNNING")

    def run(self):
        """
        主函数入口
        """
        pass
